# Datenverarbeitung - Programmierte Lösungsalternative

from collections import defaultdict
import csv
import pprint

FILE="bikeshare_data_2022.csv"
DELIMITER=","


def extrahiere_daten():
    """Extrahiere Daten und gib eine Liste mit je einem Dictionary pro
    Datensatz zurück.
    """

    with open(FILE, "r") as f:
        reader = csv.reader(f, delimiter=DELIMITER)

        # Kopfzeile für Dictionary-Schlüssel speichern
        header = reader.__next__()

        # Liste aller Datensätze
        daten = []

        for row in reader:
            datensatz = {}

            # einen einzelnen Datensatz zugänglich machen
            for h in header:
                pos = header.index(h)
                datensatz[h] = row[pos]

            # Datensatz an Liste der Daten anhängen
            daten.append(datensatz)

        # schönere Ausgabe
        #pprint.pprint(daten)

    return daten


def durchschnittliche_ausleihe(daten):
    """Berechne die durchschnittliche Menge ausgeliehener Fahrräder aus
    den übergebenen Daten.
    """

    # setze eine leere Liste als Standard-Datenwert
    station_ausleihe = defaultdict(list)

    # relevante Daten filtern
    for datensatz in daten:
        station = datensatz["station"]
        ausleihe = int(datensatz["count"])

        station_ausleihe[station].append(ausleihe)

    # Berechnung durchführen
    for k, v in station_ausleihe.items():
        summe = sum(v)
        station_ausleihe[k] = summe / len(v)

    return station_ausleihe


def ausgabe(daten):
    """Daten ausgeben"""

    for station, ausleihe in daten.items():
        print("{0}\t{1}".format(station, ausleihe))


def main():
    daten = extrahiere_daten()
    ergebnis = durchschnittliche_ausleihe(daten)
    ausgabe(ergebnis)


if __name__ == "__main__":
    main()
